==> haskell-ipynb-0.2-275.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-HRRCBGCdwBPcBmaJ8W25v
key:                  ipynb-0.2-HRRCBGCdwBPcBmaJ8W25v
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  f1417f71dd0b145aaf6fe12eb8a02b06
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-HRRCBGCdwBPcBmaJ8W25v
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    containers-0.6.7 text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.2-276-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-CjTAuQxqyd09S1Ue41N8nq
key:                  ipynb-0.2-CjTAuQxqyd09S1Ue41N8nq
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  3db4c0c15e4fb1c919f6866bf96ac6d3
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-CjTAuQxqyd09S1Ue41N8nq
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
